import type { MaintOrderStVO } from './model';

import type { ID, IDS } from '#/api/common';

import { commonExport } from '#/api/helper';
import { requestClient } from '#/api/request';

enum Api {
  maintOrderrStExport = '/eims/maintOrderSt/export',
  maintOrderrStList = '/eims/maintOrderSt/list',
  root = '/eims/maintOrderSt'
}

/**
 * 查询保养工单列表
 * @param query
 * @returns {*}
 */

export function listMaintOrderSt(params?: any) {
  return requestClient.get<MaintOrderStVO[]>(Api.maintOrderrStList, { params });
}


/**
 * 查询保养工单详细
 * @param maintOrderrStId
 */
export function getMaintOrderSt(maintOrderrStId: ID) {
  return requestClient.get<MaintOrderStVO>(`${Api.root}/${maintOrderrStId}`);
}

/**
 * 新增保养工单
 * @param data
 */
export function addMaintOrderSt(data: any) {
  return requestClient.postWithMsg<void>(Api.root, data);
}

/**
 * 修改保养工单
 * @param data
 */
export function updateMaintOrderSt(data: any) {
  return requestClient.putWithMsg<void>(Api.root, data);
}

/**
 * 删除保养工单
 * @param maintOrderrStId
 */
export function delMaintOrderSt(maintOrderrStId: IDS) {
  return requestClient.deleteWithMsg<void>(`${Api.root}/${maintOrderrStId}`);
}
/**
 * 导出
 * @param
 */
export function maintOrderrStExport(data: any) {
  return commonExport(Api.maintOrderrStExport, data);
}
